"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetIntegrationsIntegrationIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""GET /integrations/:integration_id Parameter"""


class GetIntegrationsIntegrationIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""GET /integrations/:integration_id Parameter"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


PutAssessmentPackagesRequestBodyType = Literal[
    "BEHAVIORAL",
    "VIDEO_INTERVIEW",
    "SKILLS_TEST",
    "BACKGROUND_CHECK",
    "REFERENCE_CHECK",
]


class PutAssessmentPackagesRequestBodyPackageTypedDict(TypedDict):
    id: str
    r"""A unique identifier for the assessment package."""
    type: PutAssessmentPackagesRequestBodyType
    name: str
    r"""The name of the assessment package."""
    description: str
    r"""Description about the package. Some ATSs will display this in their UI."""


class PutAssessmentPackagesRequestBodyPackage(BaseModel):
    id: str
    r"""A unique identifier for the assessment package."""

    type: PutAssessmentPackagesRequestBodyType

    name: str
    r"""The name of the assessment package."""

    description: str
    r"""Description about the package. Some ATSs will display this in their UI."""


class PutAssessmentPackagesRequestBodyTypedDict(TypedDict):
    packages: List[PutAssessmentPackagesRequestBodyPackageTypedDict]


class PutAssessmentPackagesRequestBody(BaseModel):
    packages: List[PutAssessmentPackagesRequestBodyPackage]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from kombo.utils import validate_const
import pydantic
from pydantic import Field, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


GetAtsJobsPositiveResponseEmploymentType = Union[
    Literal[
        "FULL_TIME",
        "PART_TIME",
        "CONTRACT",
        "SEASONAL",
        "INTERNSHIP",
    ],
    UnrecognizedStr,
]


GetAtsJobsPositiveResponseStatus = Union[
    Literal[
        "OPEN",
        "CLOSED",
        "DRAFT",
        "ARCHIVED",
    ],
    UnrecognizedStr,
]


Visibility = Union[
    Literal[
        "PUBLIC",
        "INTERNAL",
        "UNLISTED",
        "CONFIDENTIAL",
    ],
    UnrecognizedStr,
]


RemoteWorkStatus = Union[
    Literal[
        "REMOTE",
        "HYBRID",
        "TEMPORARY",
        "ON_SITE",
    ],
    UnrecognizedStr,
]


SalaryPeriod = Union[
    Literal[
        "YEAR",
        "MONTH",
        "TWO_WEEKS",
        "WEEK",
        "DAY",
        "HOUR",
    ],
    UnrecognizedStr,
]


class GetAtsJobsPositiveResponseLocationTypedDict(TypedDict):
    r"""The location of the listed job."""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class GetAtsJobsPositiveResponseLocation(BaseModel):
    r"""The location of the listed job."""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        nullable_fields = set(
            ["city", "country", "raw", "state", "street_1", "street_2", "zip_code"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class StageTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The application stage name. For example, \"Initial Screening\"."""
    index: NotRequired[Nullable[int]]
    r"""Numeric index following the order of the stages if they are ordered in the underlying tool."""


class Stage(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The application stage name. For example, \"Initial Screening\"."""

    index: OptionalNullable[int] = UNSET
    r"""Numeric index following the order of the stages if they are ordered in the underlying tool."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["index"])
        nullable_fields = set(["remote_id", "name", "index"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class FormatUnknownTypedDict(TypedDict):
    raw_question: NotRequired[Any]
    r"""We pass the original question data along so you can handle it."""
    type: Literal["UNKNOWN"]
    r"""When we're not able to map a specific question type yet, we will return this type. Every `UNKNOWN` question will also be parsed and unified by us at some point."""


class FormatUnknown(BaseModel):
    raw_question: Optional[Any] = None
    r"""We pass the original question data along so you can handle it."""

    TYPE: Annotated[
        Annotated[Literal["UNKNOWN"], AfterValidator(validate_const("UNKNOWN"))],
        pydantic.Field(alias="type"),
    ] = "UNKNOWN"
    r"""When we're not able to map a specific question type yet, we will return this type. Every `UNKNOWN` question will also be parsed and unified by us at some point."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["raw_question"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class FormatInformationTypedDict(TypedDict):
    type: Literal["INFORMATION"]
    r"""This is just a text block."""


class FormatInformation(BaseModel):
    TYPE: Annotated[
        Annotated[
            Literal["INFORMATION"], AfterValidator(validate_const("INFORMATION"))
        ],
        pydantic.Field(alias="type"),
    ] = "INFORMATION"
    r"""This is just a text block."""


class Option2TypedDict(TypedDict):
    id: str
    r"""The Kombo ID of this question option. Use this ID to specify the answer to this question."""
    name: str
    r"""Content of the question option."""
    remote_id: NotRequired[Nullable[str]]
    r"""ID in the connected ATS. This might be null as some systems only use the name to identify the option."""


class Option2(BaseModel):
    id: str
    r"""The Kombo ID of this question option. Use this ID to specify the answer to this question."""

    name: str
    r"""Content of the question option."""

    remote_id: OptionalNullable[str] = UNSET
    r"""ID in the connected ATS. This might be null as some systems only use the name to identify the option."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["remote_id"])
        nullable_fields = set(["remote_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class FormatMultiSelectTypedDict(TypedDict):
    options: List[Option2TypedDict]
    type: Literal["MULTI_SELECT"]


class FormatMultiSelect(BaseModel):
    options: List[Option2]

    TYPE: Annotated[
        Annotated[
            Literal["MULTI_SELECT"], AfterValidator(validate_const("MULTI_SELECT"))
        ],
        pydantic.Field(alias="type"),
    ] = "MULTI_SELECT"


class FormatDateTypedDict(TypedDict):
    type: Literal["DATE"]


class FormatDate(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["DATE"], AfterValidator(validate_const("DATE"))],
        pydantic.Field(alias="type"),
    ] = "DATE"


class FormatBooleanTypedDict(TypedDict):
    type: Literal["BOOLEAN"]


class FormatBoolean(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["BOOLEAN"], AfterValidator(validate_const("BOOLEAN"))],
        pydantic.Field(alias="type"),
    ] = "BOOLEAN"


DisplayType3 = Literal[
    "DROPDOWN",
    "RADIO",
]


class Option1TypedDict(TypedDict):
    id: str
    r"""The Kombo ID of this question option. Use this ID to specify the answer to this question."""
    name: str
    r"""Content of the question option."""
    remote_id: NotRequired[Nullable[str]]
    r"""ID in the connected ATS. This might be null as some systems only use the name to identify the option."""


class Option1(BaseModel):
    id: str
    r"""The Kombo ID of this question option. Use this ID to specify the answer to this question."""

    name: str
    r"""Content of the question option."""

    remote_id: OptionalNullable[str] = UNSET
    r"""ID in the connected ATS. This might be null as some systems only use the name to identify the option."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["remote_id"])
        nullable_fields = set(["remote_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class FormatSingleSelectTypedDict(TypedDict):
    options: List[Option1TypedDict]
    display_type: NotRequired[Nullable[DisplayType3]]
    type: Literal["SINGLE_SELECT"]


class FormatSingleSelect(BaseModel):
    options: List[Option1]

    display_type: OptionalNullable[DisplayType3] = UNSET

    TYPE: Annotated[
        Annotated[
            Literal["SINGLE_SELECT"], AfterValidator(validate_const("SINGLE_SELECT"))
        ],
        pydantic.Field(alias="type"),
    ] = "SINGLE_SELECT"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["display_type"])
        nullable_fields = set(["display_type"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class FormatFileTypedDict(TypedDict):
    accepted_mime_types: NotRequired[Nullable[List[str]]]
    max_file_size_bytes: NotRequired[Nullable[int]]
    type: Literal["FILE"]


class FormatFile(BaseModel):
    accepted_mime_types: OptionalNullable[List[str]] = UNSET

    max_file_size_bytes: OptionalNullable[int] = UNSET

    TYPE: Annotated[
        Annotated[Literal["FILE"], AfterValidator(validate_const("FILE"))],
        pydantic.Field(alias="type"),
    ] = "FILE"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["accepted_mime_types", "max_file_size_bytes"])
        nullable_fields = set(["accepted_mime_types", "max_file_size_bytes"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


DisplayType2 = Literal[
    "SLIDER",
    "FIELD",
]


class FormatNumberTypedDict(TypedDict):
    display_type: NotRequired[Nullable[DisplayType2]]
    max: NotRequired[Nullable[float]]
    min: NotRequired[Nullable[float]]
    type: Literal["NUMBER"]


class FormatNumber(BaseModel):
    display_type: OptionalNullable[DisplayType2] = "FIELD"

    max: OptionalNullable[float] = UNSET

    min: OptionalNullable[float] = UNSET

    TYPE: Annotated[
        Annotated[Literal["NUMBER"], AfterValidator(validate_const("NUMBER"))],
        pydantic.Field(alias="type"),
    ] = "NUMBER"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["display_type", "max", "min"])
        nullable_fields = set(["display_type", "max", "min"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


DisplayType1 = Literal[
    "SINGLE_LINE",
    "MULTI_LINE",
    "EMAIL",
    "URL",
]
r"""If unavailable, we recommend displaying a single-line input."""


class FormatTextTypedDict(TypedDict):
    display_type: NotRequired[Nullable[DisplayType1]]
    r"""If unavailable, we recommend displaying a single-line input."""
    max_length: NotRequired[Nullable[int]]
    type: Literal["TEXT"]


class FormatText(BaseModel):
    display_type: OptionalNullable[DisplayType1] = UNSET
    r"""If unavailable, we recommend displaying a single-line input."""

    max_length: OptionalNullable[int] = UNSET

    TYPE: Annotated[
        Annotated[Literal["TEXT"], AfterValidator(validate_const("TEXT"))],
        pydantic.Field(alias="type"),
    ] = "TEXT"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["display_type", "max_length"])
        nullable_fields = set(["display_type", "max_length"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


FormatTypedDict = TypeAliasType(
    "FormatTypedDict",
    Union[
        FormatBooleanTypedDict,
        FormatDateTypedDict,
        FormatInformationTypedDict,
        FormatMultiSelectTypedDict,
        FormatUnknownTypedDict,
        FormatTextTypedDict,
        FormatFileTypedDict,
        FormatSingleSelectTypedDict,
        FormatNumberTypedDict,
    ],
)


Format = Annotated[
    Union[
        FormatText,
        FormatNumber,
        FormatFile,
        FormatSingleSelect,
        FormatBoolean,
        FormatDate,
        FormatMultiSelect,
        FormatInformation,
        FormatUnknown,
    ],
    Field(discriminator="TYPE"),
]


GetAtsJobsPositiveResponseCategory = Literal[
    "EEO",
    "DEMOGRAPHIC",
]
r"""The category of the screening question (default `null`). \"EEO\" questions are related to Equal Employment Opportunity (e.g. \"What is your veteran status?\"), while \"DEMOGRAPHIC\" questions are for other diversity and demographic data collection."""


PreconditionOptionsTypedDict = TypeAliasType(
    "PreconditionOptionsTypedDict", Union[List[str], List[bool]]
)
r"""Where the screening question specified by `precondition_question_id` is of type `MULTI_SELECT` or `SINGLE_SELECT`, this is an array of Kombo IDs describing the valid options. If the question is of type `BOOLEAN`, this is an array containing either `true` or `false`."""


PreconditionOptions = TypeAliasType("PreconditionOptions", Union[List[str], List[bool]])
r"""Where the screening question specified by `precondition_question_id` is of type `MULTI_SELECT` or `SINGLE_SELECT`, this is an array of Kombo IDs describing the valid options. If the question is of type `BOOLEAN`, this is an array containing either `true` or `false`."""


class ScreeningQuestionTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    title: Nullable[str]
    description: Nullable[str]
    r"""Additional instructions or context. Typically a short sentence, but sometimes a long detailed description (e.g., for EEO questions). May include HTML for extra formatting."""
    category: Nullable[GetAtsJobsPositiveResponseCategory]
    r"""The category of the screening question (default `null`). \"EEO\" questions are related to Equal Employment Opportunity (e.g. \"What is your veteran status?\"), while \"DEMOGRAPHIC\" questions are for other diversity and demographic data collection."""
    required: Nullable[bool]
    format_: NotRequired[Nullable[FormatTypedDict]]
    index: NotRequired[Nullable[int]]
    precondition_question_id: NotRequired[Nullable[str]]
    r"""The Kombo ID of another screening question. Only display this question if the specified \"precondition question\" is answered with one of the values in `precondition_options`."""
    precondition_options: NotRequired[Nullable[PreconditionOptionsTypedDict]]
    r"""Where the screening question specified by `precondition_question_id` is of type `MULTI_SELECT` or `SINGLE_SELECT`, this is an array of Kombo IDs describing the valid options. If the question is of type `BOOLEAN`, this is an array containing either `true` or `false`."""


class ScreeningQuestion(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    title: Nullable[str]

    description: Nullable[str]
    r"""Additional instructions or context. Typically a short sentence, but sometimes a long detailed description (e.g., for EEO questions). May include HTML for extra formatting."""

    category: Nullable[GetAtsJobsPositiveResponseCategory]
    r"""The category of the screening question (default `null`). \"EEO\" questions are related to Equal Employment Opportunity (e.g. \"What is your veteran status?\"), while \"DEMOGRAPHIC\" questions are for other diversity and demographic data collection."""

    required: Nullable[bool]

    format_: Annotated[OptionalNullable[Format], pydantic.Field(alias="format")] = UNSET

    index: OptionalNullable[int] = UNSET

    precondition_question_id: OptionalNullable[str] = UNSET
    r"""The Kombo ID of another screening question. Only display this question if the specified \"precondition question\" is answered with one of the values in `precondition_options`."""

    precondition_options: OptionalNullable[PreconditionOptions] = UNSET
    r"""Where the screening question specified by `precondition_question_id` is of type `MULTI_SELECT` or `SINGLE_SELECT`, this is an array of Kombo IDs describing the valid options. If the question is of type `BOOLEAN`, this is an array containing either `true` or `false`."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["format", "index", "precondition_question_id", "precondition_options"]
        )
        nullable_fields = set(
            [
                "remote_id",
                "title",
                "description",
                "format",
                "category",
                "index",
                "required",
                "precondition_question_id",
                "precondition_options",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


JobPostingStatus = Literal[
    "ACTIVE",
    "INACTIVE",
    "DRAFT",
]
r"""The job posting’s current status."""


JobPostingVisibility = Literal[
    "PUBLIC",
    "INTERNAL",
    "UNLISTED",
]


class JobPostingTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    title: Nullable[str]
    r"""The job posting’s title."""
    description_html: Nullable[str]
    r"""The job posting’s description in HTML format."""
    status: Nullable[JobPostingStatus]
    r"""The job posting’s current status."""
    visibility: Nullable[JobPostingVisibility]
    url: Nullable[str]
    r"""The public URL to the job posting on the ATS platform."""


class JobPosting(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    title: Nullable[str]
    r"""The job posting’s title."""

    description_html: Nullable[str]
    r"""The job posting’s description in HTML format."""

    status: Nullable[JobPostingStatus]
    r"""The job posting’s current status."""

    visibility: Nullable[JobPostingVisibility]

    url: Nullable[str]
    r"""The public URL to the job posting on the ATS platform."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


GetAtsJobsPositiveResponseHiringTeamRole = Literal[
    "RECRUITER",
    "HIRING_MANAGER",
    "COORDINATOR",
    "SOURCER",
    "INTERVIEWER",
]


GetAtsJobsPositiveResponseScope = Literal[
    "SYSTEM",
    "JOB",
]
r"""Whether the role applies globally or is scoped to a specific job."""


GetAtsJobsPositiveResponseUnifiedType = Literal[
    "HIRING_MANAGER",
    "RECRUITER",
    "COORDINATOR",
    "SOURCER",
    "INTERVIEWER",
    "ADMIN",
]
r"""Unified role type if Kombo can map it."""


class JobRoleTypedDict(TypedDict):
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    remote_label: Nullable[str]
    r"""The label of the role."""
    scope: Nullable[GetAtsJobsPositiveResponseScope]
    r"""Whether the role applies globally or is scoped to a specific job."""
    unified_type: Nullable[GetAtsJobsPositiveResponseUnifiedType]
    r"""Unified role type if Kombo can map it."""


class JobRole(BaseModel):
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    remote_label: Nullable[str]
    r"""The label of the role."""

    scope: Nullable[GetAtsJobsPositiveResponseScope]
    r"""Whether the role applies globally or is scoped to a specific job."""

    unified_type: Nullable[GetAtsJobsPositiveResponseUnifiedType]
    r"""Unified role type if Kombo can map it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAtsJobsPositiveResponseHiringTeamTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""First name of the user."""
    last_name: Nullable[str]
    r"""Last name of the user."""
    hiring_team_roles: List[GetAtsJobsPositiveResponseHiringTeamRole]
    r"""**(⚠️ Deprecated - Use `job_roles` to access the full list of job roles.)** Array of the roles of the user for this specific job. Currently only `RECRUITER` and `HIRING_MANAGER` are mapped into our unified schema."""
    job_roles: List[JobRoleTypedDict]
    r"""Roles assigned to this user for this job.

    Visit our in-depth guide about [roles](/ats/features/roles) to learn more.

    Use `system_roles` on the `/v1/ats/users` endpoint for system-wide roles.
    """
    email: NotRequired[Nullable[str]]
    r"""Email of the user. If the email address is invalid, it will be set to null."""


class GetAtsJobsPositiveResponseHiringTeam(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""First name of the user."""

    last_name: Nullable[str]
    r"""Last name of the user."""

    hiring_team_roles: Annotated[
        List[GetAtsJobsPositiveResponseHiringTeamRole],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ]
    r"""**(⚠️ Deprecated - Use `job_roles` to access the full list of job roles.)** Array of the roles of the user for this specific job. Currently only `RECRUITER` and `HIRING_MANAGER` are mapped into our unified schema."""

    job_roles: List[JobRole]
    r"""Roles assigned to this user for this job.

    Visit our in-depth guide about [roles](/ats/features/roles) to learn more.

    Use `system_roles` on the `/v1/ats/users` endpoint for system-wide roles.
    """

    email: OptionalNullable[str] = UNSET
    r"""Email of the user. If the email address is invalid, it will be set to null."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email"])
        nullable_fields = set(["remote_id", "first_name", "last_name", "email"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetAtsJobsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""Title of the job."""
    job_code: Nullable[str]
    r"""The human readable job code. Some systems expose this as the Requisition Code/ID."""
    description: Nullable[str]
    r"""Description of the job. This field is usually returned as HTML."""
    confidential: Nullable[bool]
    r"""**(⚠️ Deprecated)** It makes more sense to store the visibility of a job in an enum. Therefore, we introduced the `visibility` enum on jobs."""
    weekly_hours: Nullable[float]
    r"""The number of hours per week an employee is expected to work."""
    category: Nullable[str]
    r"""The category of the job (often the job industry). The original string is passed through, for example \"Information Technology\", \"Quality Assurance\", \"Marketing\"."""
    department: Nullable[str]
    r"""The internal department or team the job belongs to. The original string is passed through, for example \"IT/Operations\", \"Engineering - Platform\", \"Customer Success\"."""
    post_url: Nullable[str]
    r"""The public job posting URL of the ATS itself. This can be used by external job boards to redirect applicants."""
    experience_level: Nullable[str]
    r"""The role's seniority or experience level. The original string is passed through, for example \"Mid-Senior Level\", \"5+ years\", \"Associate\", \"IC3\"."""
    salary_amount: Nullable[float]
    r"""The salary amount in the given currency."""
    salary_amount_from: Nullable[float]
    r"""The lower bound of the salary range."""
    salary_amount_to: Nullable[float]
    r"""The upper bound of the salary range."""
    salary_currency: Nullable[str]
    r"""Salary currency usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    remote_url: Nullable[str]
    r"""URL to the job posting in the source ATS system."""
    opened_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    closed_at: Nullable[datetime]
    r"""The date the job closed or is scheduled to close. A future value typically indicates the job remains open for applications until that date.

    Please use the `status` and `visibility` fields to determine if a job can be published.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    contact_id: Nullable[str]
    r"""**(⚠️ Deprecated)** The user ID of the contact person for this job. We strongly recommend using the new `hiring_team` property instead as it provides more complete and accurate information about the ATS users connected to a job."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    stages: List[StageTypedDict]
    r"""Application stages a candidate can be in for this particular job."""
    screening_questions: List[ScreeningQuestionTypedDict]
    job_postings: List[JobPostingTypedDict]
    hiring_team: List[GetAtsJobsPositiveResponseHiringTeamTypedDict]
    r"""The hiring team allows you to sync users into your system who can access the job and its applications."""
    employment_type: NotRequired[Nullable[GetAtsJobsPositiveResponseEmploymentType]]
    r"""The type of employment contract. In rare cases where can't find a clear mapping, the original string is passed through."""
    status: NotRequired[Nullable[GetAtsJobsPositiveResponseStatus]]
    r"""The job's current status.

    *Note: For any checks (e.g., \"can we publish this job?\"), always evaluate both `status` and `visibility`. For example, a job can be `status=OPEN` with `visibility=INTERNAL`, meaning only existing employees can apply.*

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    visibility: NotRequired[Nullable[Visibility]]
    r"""Describes the visibility of the job:

    - `PUBLIC`: visible to everyone, published on a job board
    - `INTERNAL`: only visible to employees of the company itself
    - `UNLISTED`: anyone can apply but only if they have the link to it
    - `CONFIDENTIAL`: nobody can apply and it's only visible in the ATS to people who were invited to it

    *Note: For any checks (e.g., \"can we publish this job?\"), always evaluate both `status` and `visibility`.*

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    remote_work_status: NotRequired[Nullable[RemoteWorkStatus]]
    r"""Defines if the job supports remote work and if so, to what extent."""
    salary_period: NotRequired[Nullable[SalaryPeriod]]
    r"""The period of time over which the salary amount is paid (not equal to the pay frequency). In rare cases where we can’t find a clear mapping, the original string is passed through."""
    location: NotRequired[Nullable[GetAtsJobsPositiveResponseLocationTypedDict]]
    r"""The location of the listed job."""


class GetAtsJobsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""Title of the job."""

    job_code: Nullable[str]
    r"""The human readable job code. Some systems expose this as the Requisition Code/ID."""

    description: Nullable[str]
    r"""Description of the job. This field is usually returned as HTML."""

    confidential: Annotated[
        Nullable[bool],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ]
    r"""**(⚠️ Deprecated)** It makes more sense to store the visibility of a job in an enum. Therefore, we introduced the `visibility` enum on jobs."""

    weekly_hours: Nullable[float]
    r"""The number of hours per week an employee is expected to work."""

    category: Nullable[str]
    r"""The category of the job (often the job industry). The original string is passed through, for example \"Information Technology\", \"Quality Assurance\", \"Marketing\"."""

    department: Nullable[str]
    r"""The internal department or team the job belongs to. The original string is passed through, for example \"IT/Operations\", \"Engineering - Platform\", \"Customer Success\"."""

    post_url: Nullable[str]
    r"""The public job posting URL of the ATS itself. This can be used by external job boards to redirect applicants."""

    experience_level: Nullable[str]
    r"""The role's seniority or experience level. The original string is passed through, for example \"Mid-Senior Level\", \"5+ years\", \"Associate\", \"IC3\"."""

    salary_amount: Nullable[float]
    r"""The salary amount in the given currency."""

    salary_amount_from: Nullable[float]
    r"""The lower bound of the salary range."""

    salary_amount_to: Nullable[float]
    r"""The upper bound of the salary range."""

    salary_currency: Nullable[str]
    r"""Salary currency usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    remote_url: Nullable[str]
    r"""URL to the job posting in the source ATS system."""

    opened_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    closed_at: Nullable[datetime]
    r"""The date the job closed or is scheduled to close. A future value typically indicates the job remains open for applications until that date.

    Please use the `status` and `visibility` fields to determine if a job can be published.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    contact_id: Annotated[
        Nullable[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ]
    r"""**(⚠️ Deprecated)** The user ID of the contact person for this job. We strongly recommend using the new `hiring_team` property instead as it provides more complete and accurate information about the ATS users connected to a job."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    stages: List[Stage]
    r"""Application stages a candidate can be in for this particular job."""

    screening_questions: List[ScreeningQuestion]

    job_postings: List[JobPosting]

    hiring_team: List[GetAtsJobsPositiveResponseHiringTeam]
    r"""The hiring team allows you to sync users into your system who can access the job and its applications."""

    employment_type: OptionalNullable[GetAtsJobsPositiveResponseEmploymentType] = UNSET
    r"""The type of employment contract. In rare cases where can't find a clear mapping, the original string is passed through."""

    status: OptionalNullable[GetAtsJobsPositiveResponseStatus] = UNSET
    r"""The job's current status.

    *Note: For any checks (e.g., \"can we publish this job?\"), always evaluate both `status` and `visibility`. For example, a job can be `status=OPEN` with `visibility=INTERNAL`, meaning only existing employees can apply.*

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    visibility: OptionalNullable[Visibility] = UNSET
    r"""Describes the visibility of the job:

    - `PUBLIC`: visible to everyone, published on a job board
    - `INTERNAL`: only visible to employees of the company itself
    - `UNLISTED`: anyone can apply but only if they have the link to it
    - `CONFIDENTIAL`: nobody can apply and it's only visible in the ATS to people who were invited to it

    *Note: For any checks (e.g., \"can we publish this job?\"), always evaluate both `status` and `visibility`.*

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    remote_work_status: OptionalNullable[RemoteWorkStatus] = UNSET
    r"""Defines if the job supports remote work and if so, to what extent."""

    salary_period: OptionalNullable[SalaryPeriod] = UNSET
    r"""The period of time over which the salary amount is paid (not equal to the pay frequency). In rare cases where we can’t find a clear mapping, the original string is passed through."""

    location: OptionalNullable[GetAtsJobsPositiveResponseLocation] = UNSET
    r"""The location of the listed job."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "employment_type",
                "status",
                "visibility",
                "remote_work_status",
                "salary_period",
                "location",
            ]
        )
        nullable_fields = set(
            [
                "name",
                "job_code",
                "description",
                "confidential",
                "weekly_hours",
                "employment_type",
                "status",
                "visibility",
                "category",
                "department",
                "post_url",
                "experience_level",
                "remote_work_status",
                "salary_amount",
                "salary_amount_from",
                "salary_amount_to",
                "salary_currency",
                "salary_period",
                "location",
                "custom_fields",
                "remote_url",
                "opened_at",
                "closed_at",
                "remote_created_at",
                "remote_updated_at",
                "contact_id",
                "remote_deleted_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetAtsJobsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetAtsJobsPositiveResponseResultTypedDict]


class GetAtsJobsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetAtsJobsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAtsJobsPositiveResponseTypedDict(TypedDict):
    data: GetAtsJobsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetAtsJobsPositiveResponse(BaseModel):
    data: GetAtsJobsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    FormatUnknown.model_rebuild()
except NameError:
    pass
try:
    FormatInformation.model_rebuild()
except NameError:
    pass
try:
    FormatMultiSelect.model_rebuild()
except NameError:
    pass
try:
    FormatDate.model_rebuild()
except NameError:
    pass
try:
    FormatBoolean.model_rebuild()
except NameError:
    pass
try:
    FormatSingleSelect.model_rebuild()
except NameError:
    pass
try:
    FormatFile.model_rebuild()
except NameError:
    pass
try:
    FormatNumber.model_rebuild()
except NameError:
    pass
try:
    FormatText.model_rebuild()
except NameError:
    pass
try:
    ScreeningQuestion.model_rebuild()
except NameError:
    pass
try:
    GetAtsJobsPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class PrehireTypedDict(TypedDict):
    r"""An object containing the temporary pre-hire information from the remote system. This ID may change or become invalid when the pre-hire becomes a full employee. Only populated when `id` is null."""

    remote_id: Nullable[str]
    r"""The temporary ID returned by the remote system when creating a pre-hire."""


class Prehire(BaseModel):
    r"""An object containing the temporary pre-hire information from the remote system. This ID may change or become invalid when the pre-hire becomes a full employee. Only populated when `id` is null."""

    remote_id: Nullable[str]
    r"""The temporary ID returned by the remote system when creating a pre-hire."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class PostHrisEmployeesFormPositiveResponseDataTypedDict(TypedDict):
    id: Nullable[str]
    r"""The Kombo id of the created employee. If null, we only created a pre-hire which shows up in the next sync after a successful onboarding."""
    remote_id: Nullable[str]
    r"""The raw ID of the created employee in the remote system. This is only populated when `id` is set (i.e., when a full employee was created). For pre-hires, use the `prehire` object instead."""
    prehire: PrehireTypedDict
    r"""An object containing the temporary pre-hire information from the remote system. This ID may change or become invalid when the pre-hire becomes a full employee. Only populated when `id` is null."""


class PostHrisEmployeesFormPositiveResponseData(BaseModel):
    id: Nullable[str]
    r"""The Kombo id of the created employee. If null, we only created a pre-hire which shows up in the next sync after a successful onboarding."""

    remote_id: Nullable[str]
    r"""The raw ID of the created employee in the remote system. This is only populated when `id` is set (i.e., when a full employee was created). For pre-hires, use the `prehire` object instead."""

    prehire: Prehire
    r"""An object containing the temporary pre-hire information from the remote system. This ID may change or become invalid when the pre-hire becomes a full employee. Only populated when `id` is null."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class PostHrisEmployeesFormPositiveResponseWarningTypedDict(TypedDict):
    message: str


class PostHrisEmployeesFormPositiveResponseWarning(BaseModel):
    message: str


class PostHrisEmployeesFormPositiveResponseTypedDict(TypedDict):
    data: PostHrisEmployeesFormPositiveResponseDataTypedDict
    warnings: List[PostHrisEmployeesFormPositiveResponseWarningTypedDict]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PostHrisEmployeesFormPositiveResponse(BaseModel):
    data: PostHrisEmployeesFormPositiveResponseData

    warnings: List[PostHrisEmployeesFormPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PostHrisEmployeesFormPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .gettoolscategoryparametercategory import GetToolsCategoryParameterCategory
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetToolsCategoryRequestTypedDict(TypedDict):
    category: GetToolsCategoryParameterCategory
    r"""GET /tools/:category Parameter"""


class GetToolsCategoryRequest(BaseModel):
    category: Annotated[
        GetToolsCategoryParameterCategory,
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""GET /tools/:category Parameter"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, NotRequired, TypedDict


GetAtsUsersPositiveResponseStatus = Literal[
    "ACTIVE",
    "INACTIVE",
]
r"""Whether the user is active or inactive. Consider this field when provisioning users from the ATS."""


GetAtsUsersPositiveResponseScope = Literal[
    "SYSTEM",
    "JOB",
]
r"""Whether the role applies globally or is scoped to a specific job."""


GetAtsUsersPositiveResponseUnifiedType = Literal[
    "HIRING_MANAGER",
    "RECRUITER",
    "COORDINATOR",
    "SOURCER",
    "INTERVIEWER",
    "ADMIN",
]
r"""Unified role type if Kombo can map it."""


class SystemRoleTypedDict(TypedDict):
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    remote_label: Nullable[str]
    r"""The label of the role."""
    scope: Nullable[GetAtsUsersPositiveResponseScope]
    r"""Whether the role applies globally or is scoped to a specific job."""
    unified_type: Nullable[GetAtsUsersPositiveResponseUnifiedType]
    r"""Unified role type if Kombo can map it."""


class SystemRole(BaseModel):
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    remote_label: Nullable[str]
    r"""The label of the role."""

    scope: Nullable[GetAtsUsersPositiveResponseScope]
    r"""Whether the role applies globally or is scoped to a specific job."""

    unified_type: Nullable[GetAtsUsersPositiveResponseUnifiedType]
    r"""Unified role type if Kombo can map it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAtsUsersPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""First name of the user."""
    last_name: Nullable[str]
    r"""Last name of the user."""
    status: Nullable[GetAtsUsersPositiveResponseStatus]
    r"""Whether the user is active or inactive. Consider this field when provisioning users from the ATS."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    system_roles: List[SystemRoleTypedDict]
    r"""System-wide roles assigned to this user in the ATS.

    Visit our in-depth guide about [roles](/ats/features/roles) to learn more.

    Note: Use `job_roles` on the `/v1/ats/jobs` endpoint for job-specific roles.
    """
    email: NotRequired[Nullable[str]]
    r"""Email of the user. If the email address is invalid, it will be set to null."""


class GetAtsUsersPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""First name of the user."""

    last_name: Nullable[str]
    r"""Last name of the user."""

    status: Nullable[GetAtsUsersPositiveResponseStatus]
    r"""Whether the user is active or inactive. Consider this field when provisioning users from the ATS."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    system_roles: List[SystemRole]
    r"""System-wide roles assigned to this user in the ATS.

    Visit our in-depth guide about [roles](/ats/features/roles) to learn more.

    Note: Use `job_roles` on the `/v1/ats/jobs` endpoint for job-specific roles.
    """

    email: OptionalNullable[str] = UNSET
    r"""Email of the user. If the email address is invalid, it will be set to null."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email"])
        nullable_fields = set(
            [
                "remote_id",
                "first_name",
                "last_name",
                "email",
                "status",
                "remote_deleted_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetAtsUsersPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetAtsUsersPositiveResponseResultTypedDict]


class GetAtsUsersPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetAtsUsersPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAtsUsersPositiveResponseTypedDict(TypedDict):
    data: GetAtsUsersPositiveResponseDataTypedDict
    status: Literal["success"]


class GetAtsUsersPositiveResponse(BaseModel):
    data: GetAtsUsersPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetAtsUsersPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenowTypedDict(TypedDict):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: NotRequired[str]
    r"""[Required] The employment ID of the employee that the absence will be deleted from."""


class DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenow(BaseModel):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: Optional[str] = None
    r"""[Required] The employment ID of the employee that the absence will be deleted from."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["employment_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFieldsTypedDict(TypedDict):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    adpworkforcenow: NotRequired[
        DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenowTypedDict
    ]
    r"""Fields specific to ADP Workforce Now."""


class DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    adpworkforcenow: Optional[DeleteHrisAbsencesAbsenceIDRequestBodyAdpworkforcenow] = (
        None
    )
    r"""Fields specific to ADP Workforce Now."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["adpworkforcenow"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class DeleteHrisAbsencesAbsenceIDRequestBodyTypedDict(TypedDict):
    remote_fields: NotRequired[
        DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFieldsTypedDict
    ]
    r"""Additional fields that we will pass through to specific HRIS systems."""


class DeleteHrisAbsencesAbsenceIDRequestBody(BaseModel):
    remote_fields: Optional[DeleteHrisAbsencesAbsenceIDRequestBodyRemoteFields] = None
    r"""Additional fields that we will pass through to specific HRIS systems."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["remote_fields"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import Field, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIdsTypedDict(
    TypedDict
):
    candidate_remote_id: str
    application_remote_id: str
    id_type: Literal["application_and_candidate_remote_ids"]
    r"""Uses the `Api/Applications/{applicantId}` endpoint to retrieve the relevant application based on the candidate ID."""


class PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds(
    BaseModel
):
    candidate_remote_id: str

    application_remote_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["application_and_candidate_remote_ids"],
            AfterValidator(validate_const("application_and_candidate_remote_ids")),
        ],
        pydantic.Field(alias="id_type"),
    ] = "application_and_candidate_remote_ids"
    r"""Uses the `Api/Applications/{applicantId}` endpoint to retrieve the relevant application based on the candidate ID."""


class PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIdsTypedDict(
    TypedDict
):
    application_remote_id: str
    job_remote_id: str
    id_type: Literal["application_and_job_remote_ids"]
    r"""Uses the `Api/Applications/ByJob/{jobId}` endpoint to retrieve the relevant application based on the job ID."""


class PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds(
    BaseModel
):
    application_remote_id: str

    job_remote_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["application_and_job_remote_ids"],
            AfterValidator(validate_const("application_and_job_remote_ids")),
        ],
        pydantic.Field(alias="id_type"),
    ] = "application_and_job_remote_ids"
    r"""Uses the `Api/Applications/ByJob/{jobId}` endpoint to retrieve the relevant application based on the job ID."""


PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict = TypeAliasType(
    "PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict",
    Union[
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIdsTypedDict,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIdsTypedDict,
    ],
)


PostAtsImportTrackedApplicationRequestBodyErecruiterUnion = Annotated[
    Union[
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds,
        PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds,
    ],
    Field(discriminator="ID_TYPE"),
]


class PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteIDTypedDict(
    TypedDict
):
    application_remote_id: str
    id_type: Literal["application_remote_id"]
    r"""Uses the `/JobApplication` ODATA endpoint to retrieve the relevant application based on the application ID."""


class PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID(
    BaseModel
):
    application_remote_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["application_remote_id"],
            AfterValidator(validate_const("application_remote_id")),
        ],
        pydantic.Field(alias="id_type"),
    ] = "application_remote_id"
    r"""Uses the `/JobApplication` ODATA endpoint to retrieve the relevant application based on the application ID."""


PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnionTypedDict = (
    PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteIDTypedDict
)


PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnion = (
    PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID
)


class PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementIDTypedDict(
    TypedDict
):
    placement_id: str
    id_type: Literal["placement_id"]
    r"""Uses the `/candidates` endpoint to retrieve all candidates, to find the relevant application based on the placement ID."""


class PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID(BaseModel):
    placement_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["placement_id"], AfterValidator(validate_const("placement_id"))
        ],
        pydantic.Field(alias="id_type"),
    ] = "placement_id"
    r"""Uses the `/candidates` endpoint to retrieve all candidates, to find the relevant application based on the placement ID."""


PostAtsImportTrackedApplicationRequestBodyRecruiteeUnionTypedDict = (
    PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementIDTypedDict
)


PostAtsImportTrackedApplicationRequestBodyRecruiteeUnion = (
    PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID
)


class PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationIDTypedDict(
    TypedDict
):
    application_id: str
    id_type: Literal["application_id"]
    r"""Uses the `/applications/{id}` endpoint to retrieve the application."""


class PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID(BaseModel):
    application_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["application_id"], AfterValidator(validate_const("application_id"))
        ],
        pydantic.Field(alias="id_type"),
    ] = "application_id"
    r"""Uses the `/applications/{id}` endpoint to retrieve the application."""


class PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationIDTypedDict(TypedDict):
    application_id: str
    id_type: Literal["application_id"]
    r"""Uses the `/v1/application/{id}` endpoint to retrieve the application."""


class PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID(BaseModel):
    application_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["application_id"], AfterValidator(validate_const("application_id"))
        ],
        pydantic.Field(alias="id_type"),
    ] = "application_id"
    r"""Uses the `/v1/application/{id}` endpoint to retrieve the application."""


PostAtsImportTrackedApplicationRequestBodyGreenhouseUnionTypedDict = (
    PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationIDTypedDict
)


PostAtsImportTrackedApplicationRequestBodyGreenhouseUnion = (
    PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID
)


PostAtsImportTrackedApplicationRequestBodyOnlyfyUnionTypedDict = (
    PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationIDTypedDict
)


PostAtsImportTrackedApplicationRequestBodyOnlyfyUnion = (
    PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID
)


class PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIdsTypedDict(
    TypedDict
):
    candidate_remote_id: str
    job_remote_id: str
    id_type: Literal["candidate_and_job_remote_ids"]
    r"""Uses the `/candidates/{candidateId}/jobs/{jobId}` endpoint to retrieve the application."""


class PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds(
    BaseModel
):
    candidate_remote_id: str

    job_remote_id: str

    ID_TYPE: Annotated[
        Annotated[
            Literal["candidate_and_job_remote_ids"],
            AfterValidator(validate_const("candidate_and_job_remote_ids")),
        ],
        pydantic.Field(alias="id_type"),
    ] = "candidate_and_job_remote_ids"
    r"""Uses the `/candidates/{candidateId}/jobs/{jobId}` endpoint to retrieve the application."""


PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnionTypedDict = PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIdsTypedDict


PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnion = (
    PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds
)


class PostAtsImportTrackedApplicationRequestBodyTypedDict(TypedDict):
    tracked_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    erecruiter: NotRequired[
        PostAtsImportTrackedApplicationRequestBodyErecruiterUnionTypedDict
    ]
    successfactors: NotRequired[
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnionTypedDict
    ]
    recruitee: NotRequired[
        PostAtsImportTrackedApplicationRequestBodyRecruiteeUnionTypedDict
    ]
    greenhouse: NotRequired[
        PostAtsImportTrackedApplicationRequestBodyGreenhouseUnionTypedDict
    ]
    onlyfy: NotRequired[PostAtsImportTrackedApplicationRequestBodyOnlyfyUnionTypedDict]
    smartrecruiters: NotRequired[
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnionTypedDict
    ]


class PostAtsImportTrackedApplicationRequestBody(BaseModel):
    tracked_at: Nullable[datetime]
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    erecruiter: Optional[PostAtsImportTrackedApplicationRequestBodyErecruiterUnion] = (
        None
    )

    successfactors: Optional[
        PostAtsImportTrackedApplicationRequestBodySuccessfactorsUnion
    ] = None

    recruitee: Optional[PostAtsImportTrackedApplicationRequestBodyRecruiteeUnion] = None

    greenhouse: Optional[PostAtsImportTrackedApplicationRequestBodyGreenhouseUnion] = (
        None
    )

    onlyfy: Optional[PostAtsImportTrackedApplicationRequestBodyOnlyfyUnion] = None

    smartrecruiters: Optional[
        PostAtsImportTrackedApplicationRequestBodySmartrecruitersUnion
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "erecruiter",
                "successfactors",
                "recruitee",
                "greenhouse",
                "onlyfy",
                "smartrecruiters",
            ]
        )
        nullable_fields = set(["tracked_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndCandidateRemoteIds.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodyErecruiterApplicationAndJobRemoteIds.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodySuccessfactorsApplicationRemoteID.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodyRecruiteePlacementID.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodyGreenhouseApplicationID.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodyOnlyfyApplicationID.model_rebuild()
except NameError:
    pass
try:
    PostAtsImportTrackedApplicationRequestBodySmartrecruitersCandidateAndJobRemoteIds.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType = Literal[
    "CV",
    "COVER_LETTER",
    "OTHER",
]


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResultTypedDict(
    TypedDict
):
    type: GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType
    id: str
    remote_id: str
    data_url: str
    file_name: str
    content_type: str
    remote_created_at: Nullable[datetime]
    r"""The date when the attachment was created.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_updated_at: Nullable[datetime]
    r"""The date when the attachment was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResult(BaseModel):
    type: GetAtsApplicationsApplicationIDAttachmentsPositiveResponseType

    id: str

    remote_id: str

    data_url: str

    file_name: str

    content_type: str

    remote_created_at: Nullable[datetime]
    r"""The date when the attachment was created.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_updated_at: Nullable[datetime]
    r"""The date when the attachment was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict(
    TypedDict
):
    results: List[
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResultTypedDict
    ]


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseData(BaseModel):
    results: List[GetAtsApplicationsApplicationIDAttachmentsPositiveResponseResult]


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict(
    TypedDict
):
    message: str


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning(BaseModel):
    message: str


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponseTypedDict(TypedDict):
    data: GetAtsApplicationsApplicationIDAttachmentsPositiveResponseDataTypedDict
    warnings: List[
        GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarningTypedDict
    ]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class GetAtsApplicationsApplicationIDAttachmentsPositiveResponse(BaseModel):
    data: GetAtsApplicationsApplicationIDAttachmentsPositiveResponseData

    warnings: List[GetAtsApplicationsApplicationIDAttachmentsPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetAtsApplicationsApplicationIDAttachmentsPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class BreakTypedDict(TypedDict):
    ended_at: datetime
    r"""End time of the break."""
    paid: bool
    r"""Whether the break is paid or unpaid."""
    started_at: datetime
    r"""Start time of the break."""


class Break(BaseModel):
    ended_at: datetime
    r"""End time of the break."""

    paid: bool
    r"""Whether the break is paid or unpaid."""

    started_at: datetime
    r"""Start time of the break."""


class GetHrisTimesheetsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employee to which the timesheet belongs. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    started_at: Nullable[datetime]
    r"""Start time of the shift, converted into UTC time zone.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    ended_at: Nullable[datetime]
    r"""End time of the shift, converted into UTC time zone.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    timezone: Nullable[str]
    r"""The ISO 8601 numeric UTC offset of the timesheet location in the format ±HH:MM (e.g., \"+02:00\", \"-05:30\"). If null, the original offset information was not available. You can use this to display the right timezone for the timesheet in the UI."""
    payable_hours: Nullable[float]
    r"""Payable hours including grace periods - only if available in the HRIS. Won't be calculated through Kombo."""
    unpaid_break_minutes: Nullable[float]
    r"""Unpaid break in minutes - will be from the HRIS or calculated by Kombo if we have concrete unpaid break times."""
    approval_status: Nullable[str]
    r"""Approval status of the shift. Can be PENDING, APPROVED, REJECTED, or null."""
    approved_at: Nullable[datetime]
    r"""The time when the shift was approved.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    comment: Nullable[str]
    r"""Comment on the shift."""
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    breaks: NotRequired[Nullable[List[BreakTypedDict]]]
    r"""Concrete times of the breaks."""


class GetHrisTimesheetsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employee to which the timesheet belongs. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    started_at: Nullable[datetime]
    r"""Start time of the shift, converted into UTC time zone.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    ended_at: Nullable[datetime]
    r"""End time of the shift, converted into UTC time zone.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    timezone: Nullable[str]
    r"""The ISO 8601 numeric UTC offset of the timesheet location in the format ±HH:MM (e.g., \"+02:00\", \"-05:30\"). If null, the original offset information was not available. You can use this to display the right timezone for the timesheet in the UI."""

    payable_hours: Nullable[float]
    r"""Payable hours including grace periods - only if available in the HRIS. Won't be calculated through Kombo."""

    unpaid_break_minutes: Nullable[float]
    r"""Unpaid break in minutes - will be from the HRIS or calculated by Kombo if we have concrete unpaid break times."""

    approval_status: Nullable[str]
    r"""Approval status of the shift. Can be PENDING, APPROVED, REJECTED, or null."""

    approved_at: Nullable[datetime]
    r"""The time when the shift was approved.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    comment: Nullable[str]
    r"""Comment on the shift."""

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    breaks: OptionalNullable[List[Break]] = UNSET
    r"""Concrete times of the breaks."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["breaks"])
        nullable_fields = set(
            [
                "remote_id",
                "started_at",
                "ended_at",
                "timezone",
                "payable_hours",
                "unpaid_break_minutes",
                "breaks",
                "approval_status",
                "approved_at",
                "comment",
                "custom_fields",
                "remote_deleted_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class GetHrisTimesheetsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisTimesheetsPositiveResponseResultTypedDict]


class GetHrisTimesheetsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisTimesheetsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetHrisTimesheetsPositiveResponseTypedDict(TypedDict):
    data: GetHrisTimesheetsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisTimesheetsPositiveResponse(BaseModel):
    data: GetHrisTimesheetsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetHrisTimesheetsPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostAtsApplicationsApplicationIDResultLinksRequestBodyAttributeTypedDict(
    TypedDict
):
    key: str
    r"""The name of the attribute"""
    value: str
    r"""The value of the attribute"""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyAttribute(BaseModel):
    key: str
    r"""The name of the attribute"""

    value: str
    r"""The value of the attribute"""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyDetailsTypedDict(TypedDict):
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    custom_field_name_prefix: str
    r"""That will be added to the attribute labels if they are used for custom fields. If you specify `Acme:` as the prefix, the custom field will be named `Acme: Score`. Putting in the name of your company/product is a good idea."""
    attributes: List[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyAttributeTypedDict
    ]


class PostAtsApplicationsApplicationIDResultLinksRequestBodyDetails(BaseModel):
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    custom_field_name_prefix: str
    r"""That will be added to the attribute labels if they are used for custom fields. If you specify `Acme:` as the prefix, the custom field will be named `Acme: Score`. Putting in the name of your company/product is a good idea."""

    attributes: List[PostAtsApplicationsApplicationIDResultLinksRequestBodyAttribute]


class PostAtsApplicationsApplicationIDResultLinksRequestBodyIcimsTypedDict(TypedDict):
    r"""Fields specific to iCIMS."""

    assessment_package_id: NotRequired[str]
    r"""The package ID of the assessment that the result link will be added to."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyIcims(BaseModel):
    r"""Fields specific to iCIMS."""

    assessment_package_id: Optional[str] = None
    r"""The package ID of the assessment that the result link will be added to."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["assessment_package_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory = (
    Literal[
        "IRC_CANDIDATE_RESUME",
        "IRC_CANDIDATE_COVERLETTER",
        "MISC",
        "IRC_INTERNAL",
    ]
)
r"""Allows you to override the document category for the url. (Default: MISC)"""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyOracleTypedDict(TypedDict):
    r"""Fields specific to Oracle."""

    override_document_category: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory
    ]
    r"""Allows you to override the document category for the url. (Default: MISC)"""
    multi_post_to_all_current_applications: NotRequired[bool]
    r"""If true, the result link will be posted to all current applications for the candidate."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyOracle(BaseModel):
    r"""Fields specific to Oracle."""

    override_document_category: Optional[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOverrideDocumentCategory
    ] = None
    r"""Allows you to override the document category for the url. (Default: MISC)"""

    multi_post_to_all_current_applications: Optional[bool] = None
    r"""If true, the result link will be posted to all current applications for the candidate."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["override_document_category", "multi_post_to_all_current_applications"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeadersTypedDict(
    TypedDict
):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: NotRequired[Nullable[str]]
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders(BaseModel):
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    on_behalf_of: Annotated[
        OptionalNullable[str], pydantic.Field(alias="On-Behalf-Of")
    ] = UNSET
    r"""ID of the the user that will show up as having performed the action in Greenhouse. We already pass a value by default, but you can use this to override it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["On-Behalf-Of"])
        nullable_fields = set(["On-Behalf-Of"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouseTypedDict(
    TypedDict
):
    r"""Fields specific to Greenhouse."""

    post_headers: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeadersTypedDict
    ]
    r"""Headers we will pass with `POST` requests to Greenhouse."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouse(BaseModel):
    r"""Fields specific to Greenhouse."""

    post_headers: Optional[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders
    ] = None
    r"""Headers we will pass with `POST` requests to Greenhouse."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["post_headers"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkableTypedDict(
    TypedDict
):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: NotRequired[str]
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkable(BaseModel):
    r"""Workable specific remote fields for ATS actions."""

    on_behalf_of_user_remote_id: Optional[str] = None
    r"""The remote ID of the user that will be displayed in the UI as the one that performed the action."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["on_behalf_of_user_remote_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFieldsTypedDict(
    TypedDict
):
    r"""Additional fields that we will pass through to specific ATS systems."""

    icims: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyIcimsTypedDict
    ]
    r"""Fields specific to iCIMS."""
    oracle: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyOracleTypedDict
    ]
    r"""Fields specific to Oracle."""
    greenhouse: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouseTypedDict
    ]
    r"""Fields specific to Greenhouse."""
    workable: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkableTypedDict
    ]
    r"""Workable specific remote fields for ATS actions."""


class PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific ATS systems."""

    icims: Optional[PostAtsApplicationsApplicationIDResultLinksRequestBodyIcims] = None
    r"""Fields specific to iCIMS."""

    oracle: Optional[PostAtsApplicationsApplicationIDResultLinksRequestBodyOracle] = (
        None
    )
    r"""Fields specific to Oracle."""

    greenhouse: Optional[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyGreenhouse
    ] = None
    r"""Fields specific to Greenhouse."""

    workable: Optional[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyWorkable
    ] = None
    r"""Workable specific remote fields for ATS actions."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["icims", "oracle", "greenhouse", "workable"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostAtsApplicationsApplicationIDResultLinksRequestBodyTypedDict(TypedDict):
    label: str
    r"""If we can display a display name for the link, we will use this label."""
    url: str
    r"""URL of the link."""
    details: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyDetailsTypedDict
    ]
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """
    remote_fields: NotRequired[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFieldsTypedDict
    ]
    r"""Additional fields that we will pass through to specific ATS systems."""


class PostAtsApplicationsApplicationIDResultLinksRequestBody(BaseModel):
    label: str
    r"""If we can display a display name for the link, we will use this label."""

    url: str
    r"""URL of the link."""

    details: Optional[PostAtsApplicationsApplicationIDResultLinksRequestBodyDetails] = (
        None
    )
    r"""Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

    We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.
    """

    remote_fields: Optional[
        PostAtsApplicationsApplicationIDResultLinksRequestBodyRemoteFields
    ] = None
    r"""Additional fields that we will pass through to specific ATS systems."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details", "remote_fields"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    PostAtsApplicationsApplicationIDResultLinksRequestBodyPostHeaders.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypedDict


PostHrisAbsencesPositiveResponseUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The unit of time for this absence. Can be `HOURS` or `DAYS`."""


PostHrisAbsencesPositiveResponseStatus = Union[
    Literal[
        "REQUESTED",
        "APPROVED",
        "DECLINED",
        "CANCELLED",
        "DELETED",
    ],
    UnrecognizedStr,
]


class PostHrisAbsencesPositiveResponseDataTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employee to which the absence belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    start_date: Nullable[Any]
    r"""The date this absence starts in the `yyyy-MM-dd` format."""
    end_date: Nullable[Any]
    r"""The date this absence ends in the `yyyy-MM-dd` format."""
    start_half_day: Nullable[bool]
    r"""`true` if the absence starts in the middle of the day, `false` if not, and `null` if the absence type doesn't support half-day absences. For multi-day absences, this only applies to the first day of the absence."""
    end_half_day: Nullable[bool]
    r"""`true` if the absence ends in the middle of the day, `false` if not, and `null` if the absence type doesn't support half-day absences. For multi-day absences, this only applies to the last day of the absence."""
    start_time: Nullable[Any]
    r"""The time at which this absence starts. Follows the format `HH:mm:ss` (e.g., `14:45:15`)."""
    end_time: Nullable[Any]
    r"""The time at which this absence ends. Follows the format `HH:mm:ss` (e.g., `14:45:15`)."""
    amount: Nullable[float]
    r"""The amount of time this absence takes."""
    unit: Nullable[PostHrisAbsencesPositiveResponseUnit]
    r"""The unit of time for this absence. Can be `HOURS` or `DAYS`."""
    employee_note: Nullable[str]
    r"""A note the employee has added to this absence."""
    type_id: Nullable[str]
    r"""The Kombo absence type ID of this absence."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    status: NotRequired[Nullable[PostHrisAbsencesPositiveResponseStatus]]
    r"""The absence’s current status. In rare cases where we can’t find a clear mapping, the original string is passed through."""


class PostHrisAbsencesPositiveResponseData(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employee to which the absence belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    start_date: Nullable[Any]
    r"""The date this absence starts in the `yyyy-MM-dd` format."""

    end_date: Nullable[Any]
    r"""The date this absence ends in the `yyyy-MM-dd` format."""

    start_half_day: Nullable[bool]
    r"""`true` if the absence starts in the middle of the day, `false` if not, and `null` if the absence type doesn't support half-day absences. For multi-day absences, this only applies to the first day of the absence."""

    end_half_day: Nullable[bool]
    r"""`true` if the absence ends in the middle of the day, `false` if not, and `null` if the absence type doesn't support half-day absences. For multi-day absences, this only applies to the last day of the absence."""

    start_time: Nullable[Any]
    r"""The time at which this absence starts. Follows the format `HH:mm:ss` (e.g., `14:45:15`)."""

    end_time: Nullable[Any]
    r"""The time at which this absence ends. Follows the format `HH:mm:ss` (e.g., `14:45:15`)."""

    amount: Nullable[float]
    r"""The amount of time this absence takes."""

    unit: Nullable[PostHrisAbsencesPositiveResponseUnit]
    r"""The unit of time for this absence. Can be `HOURS` or `DAYS`."""

    employee_note: Nullable[str]
    r"""A note the employee has added to this absence."""

    type_id: Nullable[str]
    r"""The Kombo absence type ID of this absence."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    status: OptionalNullable[PostHrisAbsencesPositiveResponseStatus] = UNSET
    r"""The absence’s current status. In rare cases where we can’t find a clear mapping, the original string is passed through."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["status"])
        nullable_fields = set(
            [
                "remote_id",
                "start_date",
                "end_date",
                "start_half_day",
                "end_half_day",
                "start_time",
                "end_time",
                "amount",
                "unit",
                "status",
                "employee_note",
                "type_id",
                "remote_deleted_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


class PostHrisAbsencesPositiveResponseWarningTypedDict(TypedDict):
    message: str


class PostHrisAbsencesPositiveResponseWarning(BaseModel):
    message: str


class PostHrisAbsencesPositiveResponseTypedDict(TypedDict):
    data: PostHrisAbsencesPositiveResponseDataTypedDict
    warnings: List[PostHrisAbsencesPositiveResponseWarningTypedDict]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PostHrisAbsencesPositiveResponse(BaseModel):
    data: PostHrisAbsencesPositiveResponseData

    warnings: List[PostHrisAbsencesPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PostHrisAbsencesPositiveResponse.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostHrisAbsencesRequestBodyStatus = Literal[
    "REQUESTED",
    "APPROVED",
]
r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""


PostHrisAbsencesRequestBodyUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""


BenefitTypeID = Literal[
    "Delegated Payment",
    "No Right to Benefit",
    "Direct payment",
]
r"""Required for illness absences. Benefit type: Delegated Payment, No Right to Benefit, or Direct payment."""


class A3innuvanominaTypedDict(TypedDict):
    r"""Fields specific to A3 Innuva Nómina."""

    benefit_type_id: NotRequired[BenefitTypeID]
    r"""Required for illness absences. Benefit type: Delegated Payment, No Right to Benefit, or Direct payment."""


class A3innuvanomina(BaseModel):
    r"""Fields specific to A3 Innuva Nómina."""

    benefit_type_id: Optional[BenefitTypeID] = None
    r"""Required for illness absences. Benefit type: Delegated Payment, No Right to Benefit, or Direct payment."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["benefit_type_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict(TypedDict):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: NotRequired[str]
    r"""[Required] The employment ID of the employee that the absence will be added to."""
    paid_leave: NotRequired[bool]
    r"""Whether the absence is paid or not."""


class PostHrisAbsencesRequestBodyAdpworkforcenow(BaseModel):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: Optional[str] = None
    r"""[Required] The employment ID of the employee that the absence will be added to."""

    paid_leave: Optional[bool] = None
    r"""Whether the absence is paid or not."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["employment_id", "paid_leave"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostHrisAbsencesRequestBodyRemoteFieldsTypedDict(TypedDict):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    a3innuvanomina: NotRequired[A3innuvanominaTypedDict]
    r"""Fields specific to A3 Innuva Nómina."""
    adpworkforcenow: NotRequired[PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict]
    r"""Fields specific to ADP Workforce Now."""


class PostHrisAbsencesRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    a3innuvanomina: Optional[A3innuvanomina] = None
    r"""Fields specific to A3 Innuva Nómina."""

    adpworkforcenow: Optional[PostHrisAbsencesRequestBodyAdpworkforcenow] = None
    r"""Fields specific to ADP Workforce Now."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["a3innuvanomina", "adpworkforcenow"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostHrisAbsencesRequestBodyTypedDict(TypedDict):
    employee_id: str
    r"""The ID of the employee in Kombo or their ID in the remote system by prefixing it with `remote:` (e.g., `remote:12312`)"""
    absence_type_id: str
    r"""The ID of the absence type in Kombo (not its `remote_id`)."""
    start_date: datetime
    r"""The date that the absence starts. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    end_date: datetime
    r"""When the absence ends.The date that the absence ends. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    employee_note: Nullable[str]
    r"""A note describing the reason for this absence."""
    status: NotRequired[PostHrisAbsencesRequestBodyStatus]
    r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""
    start_half_day: NotRequired[bool]
    r"""`true` if the absence should start in the middle of the day."""
    end_half_day: NotRequired[bool]
    r"""`true` if the absence should end in the middle of the day."""
    amount: NotRequired[float]
    r"""The amount of time of the absence. Specifying this also requires specifying `unit`. This is supported by very few tools."""
    unit: NotRequired[PostHrisAbsencesRequestBodyUnit]
    r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""
    start_time: NotRequired[str]
    r"""The time of when the absence begins. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `start_time` is specified, `end_time` has to be specified as well."""
    end_time: NotRequired[str]
    r"""The time of when the absence ends. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `end_time` is specified, `start_time` has to be specified as well."""
    remote_fields: NotRequired[PostHrisAbsencesRequestBodyRemoteFieldsTypedDict]
    r"""Additional fields that we will pass through to specific HRIS systems."""


class PostHrisAbsencesRequestBody(BaseModel):
    employee_id: str
    r"""The ID of the employee in Kombo or their ID in the remote system by prefixing it with `remote:` (e.g., `remote:12312`)"""

    absence_type_id: str
    r"""The ID of the absence type in Kombo (not its `remote_id`)."""

    start_date: datetime
    r"""The date that the absence starts. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    end_date: datetime
    r"""When the absence ends.The date that the absence ends. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    employee_note: Nullable[str]
    r"""A note describing the reason for this absence."""

    status: Optional[PostHrisAbsencesRequestBodyStatus] = "REQUESTED"
    r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""

    start_half_day: Optional[bool] = False
    r"""`true` if the absence should start in the middle of the day."""

    end_half_day: Optional[bool] = False
    r"""`true` if the absence should end in the middle of the day."""

    amount: Optional[float] = None
    r"""The amount of time of the absence. Specifying this also requires specifying `unit`. This is supported by very few tools."""

    unit: Optional[PostHrisAbsencesRequestBodyUnit] = None
    r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""

    start_time: Optional[str] = None
    r"""The time of when the absence begins. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `start_time` is specified, `end_time` has to be specified as well."""

    end_time: Optional[str] = None
    r"""The time of when the absence ends. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `end_time` is specified, `start_time` has to be specified as well."""

    remote_fields: Optional[PostHrisAbsencesRequestBodyRemoteFields] = None
    r"""Additional fields that we will pass through to specific HRIS systems."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "status",
                "start_half_day",
                "end_half_day",
                "amount",
                "unit",
                "start_time",
                "end_time",
                "remote_fields",
            ]
        )
        nullable_fields = set(["employee_note"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
